@@ -52,7 +52,7 @@ def check_score_accuracy(grades) -> dict:
 
 
 def generate_sample(config) -> dict:
-    """Generate a sample grades YAML config file."""
+    """Generate a sample grades JSON config file."""
     if os.path.exists(config.path):
         err_msg = f"Will not overwrite existing {config.path}"
         click.secho(err_msg, fg="bright_yellow")
@@ -64,7 +64,7 @@ def generate_sample(config) -> dict:
 
 
 def generate_sample_overwrite(config) -> dict:
-    """Generate a sample grades YAML config file: overwrite if it exists."""
+    """Generate a sample grades JSON config file: overwrite if it exists."""
     if os.path.exists(config.path):
         click.secho(f"Overwriting {config.path}", fg="bright_blue")
     else:
@@ -75,7 +75,7 @@ def generate_sample_overwrite(config) -> dict:
     )
 
 
-def plot_modules(grades: Grades, options: dict = {}) -> dict:
+def plot_modules(grades: Grades, api=False, options: dict = {}) -> dict:
     """
     Plot modules over time with additional information and save the generated
     plot to `path`. It might be a good idea to refactor this gigantic function
@@ -375,10 +375,14 @@ def plot_modules(grades: Grades, options: dict = {}) -> dict:
         filepath = Path(options.get("path", "")) / filename
 
     if os.path.exists(filepath):
+        err_msg = f"The output destination file already exists: {filepath}"
         click.secho(
-            f"The output destination file already exists: {filepath}",
+            err_msg,
             fg="bright_yellow",
         )
+        # don't ask anything and return early when called with the `api` flag
+        if api:
+            return {"ok": False, "error": err_msg}
 
         if not click.confirm(
             "Would you like to overwrite this file?",
